# Generated by Django 4.1.2 on 2022-11-30 16:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        (
            "meta_screening",
            "0057_alter_historicalscreeningpartone_calculated_egfr_value_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="eligible",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to now", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="reasons_ineligible",
            field=models.TextField(
                max_length=150, null=True, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="eligible",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to now", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="reasons_ineligible",
            field=models.TextField(
                max_length=150, null=True, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="eligible",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to now", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="reasons_ineligible",
            field=models.TextField(
                max_length=150, null=True, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="eligible",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to now", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_ineligible",
            field=models.TextField(
                max_length=150, null=True, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="eligible",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to now", null=True
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_ineligible",
            field=models.TextField(
                max_length=150, null=True, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]
