# Generated by Django 3.0.6 on 2020-05-16 22:50

import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0035_auto_20200517_0128"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmissedvisit",
            name="contact_attempts_explained",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If less than 3 attempts, please explain",
            ),
        ),
        migrations.AddField(
            model_name="historicalmissedvisit",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                ],
                default="alive",
                max_length=25,
                verbose_name="Survival status",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="missedvisit",
            name="contact_attempts_explained",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If less than 3 attempts, please explain",
            ),
        ),
        migrations.AddField(
            model_name="missedvisit",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                ],
                default="alive",
                max_length=25,
                verbose_name="Survival status",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalmissedvisit",
            name="contact_last_date",
            field=models.DateField(
                blank=True,
                default=edc_utils.date.get_utcnow,
                null=True,
                validators=[
                    edc_model.validators.date.date_not_future,
                    edc_protocol.validators.date_not_before_study_start,
                ],
                verbose_name="Date of last telephone contact/attempt",
            ),
        ),
        migrations.AlterField(
            model_name="missedvisit",
            name="contact_last_date",
            field=models.DateField(
                blank=True,
                default=edc_utils.date.get_utcnow,
                null=True,
                validators=[
                    edc_model.validators.date.date_not_future,
                    edc_protocol.validators.date_not_before_study_start,
                ],
                verbose_name="Date of last telephone contact/attempt",
            ),
        ),
    ]
