# Generated by Django 5.0.1 on 2024-02-14 03:17

import uuid

import _socket
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0171_alter_glucose_endpoint_today_and_more"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RenameModel(
            old_name="historicalbloodresultsglu",
            new_name="historicalglucosefbg",
        ),
        migrations.RenameModel(
            old_name="bloodresultsglu",
            new_name="glucosefbg",
        ),
        migrations.AlterModelOptions(
            name="glucosefbg",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "verbose_name": "Glucose (FBG)",
                "verbose_name_plural": "Glucose (FBG)",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalglucosefbg",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Glucose (FBG)",
                "verbose_name_plural": "historical Glucose (FBG)",
            },
        ),
        migrations.RenameIndex(
            model_name="glucosefbg",
            new_name="meta_subjec_subject_e585cf_idx",
            old_name="meta_subjec_subject_199c7b_idx",
        ),
        migrations.RenameIndex(
            model_name="glucosefbg",
            new_name="meta_subjec_subject_b1d1d3_idx",
            old_name="meta_subjec_subject_93fda3_idx",
        ),
    ]
