# Generated by Django 5.1.2 on 2024-11-18 02:18

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0213_rename_bloodresultslipid_bloodresultslipids_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstudymedication",
            name="stock_codes",
            field=models.CharField(
                blank=True,
                help_text="Enter the medication bottle barcode or bacodes seperated by comma, no spaces",
                max_length=30,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        regex="^([a-zA-Z0-9]{6})(,[a-zA-Z0-9]{6})*$"
                    )
                ],
            ),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="stock_codes",
            field=models.CharField(
                blank=True,
                help_text="Enter the medication bottle barcode or bacodes seperated by comma, no spaces",
                max_length=30,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        regex="^([a-zA-Z0-9]{6})(,[a-zA-Z0-9]{6})*$"
                    )
                ],
            ),
        ),
    ]
