# Generated by Django 5.0.8 on 2024-08-21 22:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0027_auto_20240822_0140"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="glucosesummary",
            options={
                "default_permissions": ("view", "export", "viewallsites"),
                "managed": False,
                "verbose_name": "Glucose Summary",
                "verbose_name_plural": "Glucose Summary",
            },
        ),
    ]
