# Generated by Django 3.2.11 on 2022-01-28 14:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0029_auto_20211123_1645"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalscreeningpartone",
            name="diet_and_lifestyle",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartone",
            name="diet_and_lifestyle_duration",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartthree",
            name="diet_and_lifestyle",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningpartthree",
            name="diet_and_lifestyle_duration",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningparttwo",
            name="diet_and_lifestyle",
        ),
        migrations.RemoveField(
            model_name="historicalscreeningparttwo",
            name="diet_and_lifestyle_duration",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectscreening",
            name="diet_and_lifestyle",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectscreening",
            name="diet_and_lifestyle_duration",
        ),
        migrations.RemoveField(
            model_name="subjectscreening",
            name="diet_and_lifestyle",
        ),
        migrations.RemoveField(
            model_name="subjectscreening",
            name="diet_and_lifestyle_duration",
        ),
    ]
