# Generated by Django 4.2.11 on 2024-05-16 00:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "meta_subject",
            "0200_rename_fasting_duration_minutes_bloodresultsins_fasting_duration_delta_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsins",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosefbg",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
    ]
