# Generated by Django 5.0.4 on 2024-04-18 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0058_dmreferral_referral_note_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="reason",
            field=models.CharField(
                choices=[
                    ("pregnancy", "Pregnancy"),
                    ("sae", "Participant is experiencing a serious adverse event"),
                    (
                        "clinician",
                        "Other condition that justifies discontinuation of treatment in the clinician's opinion (specify below)",
                    ),
                    ("investigator", " Investigator decision"),
                    ("referral", "Referral to Diabetes clinic"),
                    ("patient", "Patient decision"),
                    ("OTHER", "Other reason (specify below)"),
                ],
                max_length=25,
                verbose_name="Reason for stopping study medication",
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="reason",
            field=models.CharField(
                choices=[
                    ("pregnancy", "Pregnancy"),
                    ("sae", "Participant is experiencing a serious adverse event"),
                    (
                        "clinician",
                        "Other condition that justifies discontinuation of treatment in the clinician's opinion (specify below)",
                    ),
                    ("investigator", " Investigator decision"),
                    ("referral", "Referral to Diabetes clinic"),
                    ("patient", "Patient decision"),
                    ("OTHER", "Other reason (specify below)"),
                ],
                max_length=25,
                verbose_name="Reason for stopping study medication",
            ),
        ),
    ]
