# Generated by Django 3.2.11 on 2022-03-09 19:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0099_auto_20220309_2218"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="bhcg_value",
            field=models.CharField(
                choices=[
                    ("POS", "Positive"),
                    ("NEG", "Negative"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Urine βhCG result",
            ),
        ),
        migrations.AlterField(
            model_name="urinepregnancy",
            name="bhcg_value",
            field=models.CharField(
                choices=[
                    ("POS", "Positive"),
                    ("NEG", "Negative"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Urine βhCG result",
            ),
        ),
    ]
