# Generated by Django 4.2.11 on 2024-06-18 03:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0003_auto_20240618_0505"),
    ]

    operations = [
        migrations.AlterModelTable(
            name="patienthistorymissingbaselinecd4",
            table="patient_history_missing_baseline_cd4_view",
        ),
    ]
